[![PyPI version](https://badge.fury.io/py/dashport.svg)](https://badge.fury.io/py/dashport) [![Documentation Status](https://readthedocs.org/projects/dashport/badge/?version=latest)](https://dashport.readthedocs.io/en/latest/?badge=latest)

# dashport

Dashport - An easy and safe way to use curses

## Installation

You can install from source code by cloning down this repo and running:

```
pip install .
```

Alternatively, use this to install from PyPI:

```
pip install dashport
```
